Low-level functions to detect the linux version on the system. See linux_version.
Enums
Functions
- linux_
version - Returns the Linux version of the current platform.
Low-level functions to detect the linux version on the system. See linux_version.