pub struct Cuda {
pub version: Version,
}Expand description
Cuda virtual package description
Fields
version: VersionThe maximum supported Cuda version.
Implementations
Sourceimpl Cuda
impl Cuda
Sourcepub fn current(cache_dir: Option<&Path>) -> Option<Self>
pub fn current(cache_dir: Option<&Path>) -> Option<Self>
Returns the maximum Cuda version available on the current platform.
See cuda::cuda_info for the cache_dir semantics.
Sourcepub fn detect_with_cache_dir(
ov: Option<&Override>,
cache_dir: Option<&Path>,
) -> Result<Option<Self>, DetectVirtualPackageError>
pub fn detect_with_cache_dir( ov: Option<&Override>, cache_dir: Option<&Path>, ) -> Result<Option<Self>, DetectVirtualPackageError>
Detect the Cuda virtual package with the given override, using cache_dir for the on-disk
detection cache.